==> monodevelop_4.0.12+dfsg.orig.tar.gz: monodevelop-4.0.12/src/addins/MonoDevelop.DocFood/MonoDevelop.DocFood.Options/ExpansionsPanelWidget.cs <==
// 
// ExpansionsPanelWidget.cs
//  
// Author:
//       Mike Krüger <mkrueger@novell.com>
// 
// Copyright (c) 2010 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using MonoDevelop.Ide.Gui.Dialogs;

namespace MonoDevelop.DocFood.Options
{
	[System.ComponentModel.ToolboxItem(true)]
	public partial class ExpansionsPanelWidget : Gtk.Bin
	{
//		DocConfig config;
		
		public ExpansionsPanelWidget (DocConfig config)
		{
//			this.config = config;
			this.Build ();
		}
	}
	
		
	/// <summary>
	/// Expansions panel.
	/// </summary>
	public class ExpansionsPanel : OptionsPanel
	{
		ExpansionsPanelWidget panel;

		/// <summary>
		/// Creates the panel widget.
		/// </summary>
		/// <returns>
		/// The panel widget.
		/// </returns>
		public override Gtk.Widget CreatePanelWidget ()
		{
			panel = new ExpansionsPanelWidget (DocConfig.Instance);
			return panel;
		}
		
		public override void ApplyChanges ()
		{
		//	panel.Store ();
		}
	}
}

==> monodevelop_4.2.2.orig.tar.gz: monodevelop-4.2.2/src/addins/MonoDevelop.DocFood/MonoDevelop.DocFood.Options/ExpansionsPanelWidget.cs <==
// 
// ExpansionsPanelWidget.cs
//  
// Author:
//       Mike Krüger <mkrueger@novell.com>
// 
// Copyright (c) 2010 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using MonoDevelop.Ide.Gui.Dialogs;

namespace MonoDevelop.DocFood.Options
{
	[System.ComponentModel.ToolboxItem(true)]
	partial class ExpansionsPanelWidget : Gtk.Bin
	{
//		DocConfig config;
		
		public ExpansionsPanelWidget (DocConfig config)
		{
//			this.config = config;
			this.Build ();
		}
	}
	
		
	/// <summary>
	/// Expansions panel.
	/// </summary>
	class ExpansionsPanel : OptionsPanel
	{
		ExpansionsPanelWidget panel;

		/// <summary>
		/// Creates the panel widget.
		/// </summary>
		/// <returns>
		/// The panel widget.
		/// </returns>
		public override Gtk.Widget CreatePanelWidget ()
		{
			panel = new ExpansionsPanelWidget (DocConfig.Instance);
			return panel;
		}
		
		public override void ApplyChanges ()
		{
		//	panel.Store ();
		}
	}
}
